==> limitorderv2-sdk-0.1.2.tgz: package/src/entities/eip712.ts <==
import { getMessage } from 'eip-712';
import { ethers } from 'ethers';
import { types, ChainId, name, contract } from '../constants'

export interface Domain {
    name: string,
    chainId: ChainId,
    verifyingContract: string
}

export interface Message {
    maker: string,
    tokenIn: string,
    tokenOut: string,
    amountIn: string,
    amountOut: string,
    recipient: string,
    startTime: string,
    endTime: string,
    stopPrice: string,
    oracleAddress: string,
    oracleData: string
}

export const getSignature = (message: Message, chainId: ChainId, privateKey: string) => {
    let domain: Domain = {
        name: name,
        chainId: chainId,
        verifyingContract: contract
    }
    return sign({types, primaryType: "LimitOrder", domain, message}, privateKey);
}

export const getTypedData = (message: Message, chainId: ChainId) => {
    let domain: Domain = {
        name: name,
        chainId: chainId,
        verifyingContract: contract
    }
    return ({types, primaryType: "LimitOrder", domain, message});
}
  
const sign = (typedData: any, privateKey: string) => {
    let message = getMessage(typedData, true)
    const signingKey = new ethers.utils.SigningKey(privateKey);
    const { v, r, s } = signingKey.signDigest(message);
    return { v, r, s };
}

export const getSignatureWithProvider = async (message: Message, chainId: ChainId, provider: ethers.providers.Web3Provider):
    Promise<{ v: number, r: string, s: string }> => {
    const typedData = getTypedData(message, chainId);
    const signature = await provider.send('eth_signTypedData_v4', [message.maker, typedData]);
    const { v, r, s } = ethers.utils.splitSignature(signature);
    return { v, r, s };
}

==> limitorderv2-sdk-0.1.9.tgz: package/src/entities/eip712.ts <==
import { getMessage } from 'eip-712';
import { ethers } from 'ethers';
import { types, ChainId, name, getVerifyingContract } from '../constants'

export interface Domain {
    name: string,
    chainId: ChainId,
    verifyingContract: string
}

export interface Message {
    maker: string,
    tokenIn: string,
    tokenOut: string,
    amountIn: string,
    amountOut: string,
    recipient: string,
    startTime: string,
    endTime: string,
    stopPrice: string,
    oracleAddress: string,
    oracleData: string
}

export const getSignature = (message: Message, chainId: ChainId, privateKey: string) => {
    let domain: Domain = {
        name: name,
        chainId: chainId,
        verifyingContract: getVerifyingContract(chainId)
    }
    return sign({types, primaryType: "LimitOrder", domain, message}, privateKey);
}

export const getTypedData = (message: Message, chainId: ChainId) => {
    let domain: Domain = {
        name: name,
        chainId: chainId,
        verifyingContract: getVerifyingContract(chainId)
    }
    return { types, primaryType: "LimitOrder", domain, message };
}
  
const sign = (typedData: any, privateKey: string) => {
    let message = getMessage(typedData, true)
    const signingKey = new ethers.utils.SigningKey(privateKey);
    const { v, r, s } = signingKey.signDigest(message);
    return { v, r, s };
}

export const getSignatureWithProvider = async (message: Message, chainId: ChainId, provider: ethers.providers.Web3Provider):
Promise<{ v: number, r: string, s: string }> => {
    const typedData = getTypedData(message, chainId);
    console.log('typedData: ', typedData);
    const signature = await provider.send('eth_signTypedData_v4', [message.maker, JSON.stringify(typedData)]);
    const { v, r, s } = ethers.utils.splitSignature(signature);
    return { v, r, s };
}
